Structs
- Agent
Attribution - Attribution of a file to an agent
- Agent
Invocation - Agent invocation tracking
- Agent
Statistics - Statistics for an individual agent
- Agent
Tool Correlation - Correlation between agents and tools
- Agent
Type - Analyzer
Config - Configuration for the analyzer
- Collaboration
Pattern - Collaboration patterns between agents
- File
Operation - File operations extracted from tool uses
- Message
Id - Session
Analysis - Analysis results for a session
- Session
Entry - Parse JSONL session entries from Claude Code
- Session
Id - Newtype wrappers for better type safety
- Tool
Analysis - Complete tool usage analysis
- Tool
Chain - Sequence of tools used together
- Tool
Invocation - Tool invocation extracted from Bash commands
- Tool
Result Content - Tool
Statistics - Statistics for a specific tool
Enums
- Content
Block - File
OpType - Message
- Tool
Category - Category of tool being used
Functions
- extract_
file_ path - Helper to extract file path from various tool inputs
- get_
agent_ category - Used in integration tests and public API
- normalize_
agent_ name - Agent type utilities Used in integration tests and public API
- parse_
timestamp - Parse an ISO 8601 timestamp string into a
jiff::Timestamp