pub fn load_user_patterns() -> Result<Vec<ToolPattern>>Expand description
Load user-defined patterns from config file
Errors
Returns an error if the config file exists but cannot be read or parsed
pub fn load_user_patterns() -> Result<Vec<ToolPattern>>Load user-defined patterns from config file
Returns an error if the config file exists but cannot be read or parsed