pub fn create_matcher() -> Box<dyn PatternMatcher>Expand description
Factory function to create a new pattern matcher
Returns Terraphim matcher if the feature is enabled, otherwise returns the default Aho-Corasick implementation
pub fn create_matcher() -> Box<dyn PatternMatcher>Factory function to create a new pattern matcher
Returns Terraphim matcher if the feature is enabled, otherwise returns the default Aho-Corasick implementation